"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const test_commons_1 = require("../../../../../test/test-commons");
const getGraphQLStringTypeByPath_1 = require("./getGraphQLStringTypeByPath");
const chai_1 = require("chai");
describe('getGraphQLStringTypeByPath', async () => {
    let schema;
    before(async () => {
        schema = await test_commons_1.getMockSchema();
    });
    it('with mutation startField', () => {
        const updatePetField = schema.getMutationType()?.getFields()['update_Pet'];
        if (updatePetField == null)
            throw new Error();
        const petType = getGraphQLStringTypeByPath_1.getGraphQLStringTypeByPath(schema, updatePetField, []);
        chai_1.expect(petType).to.eq('PetDTO');
        const identificationNumberType = getGraphQLStringTypeByPath_1.getGraphQLStringTypeByPath(schema, updatePetField, ['identificationNumber']);
        chai_1.expect(identificationNumberType).to.eq('String');
    });
    it('with query startField', () => {
        const petField = schema.getQueryType()?.getFields()['pet'];
        if (petField == null)
            throw new Error();
        const petType = getGraphQLStringTypeByPath_1.getGraphQLStringTypeByPath(schema, petField, []);
        chai_1.expect(petType).to.eq('PetDTO');
        const identificationNumberType = getGraphQLStringTypeByPath_1.getGraphQLStringTypeByPath(schema, petField, ['identificationNumber']);
        chai_1.expect(identificationNumberType).to.eq('String');
    });
    it('in root of query', () => {
        const petField = schema.getQueryType()?.getFields()['pet'];
        if (petField == null)
            throw new Error();
        const petType = getGraphQLStringTypeByPath_1.getGraphQLStringTypeByPath(schema, petField, []);
        chai_1.expect(petType).to.eq('PetDTO');
        const petListField = schema.getQueryType()?.getFields()['petList'];
        if (petListField == null)
            throw new Error();
        const petListType = getGraphQLStringTypeByPath_1.getGraphQLStringTypeByPath(schema, petListField, []);
        chai_1.expect(petListType).to.eq('[PetDTO]');
    });
    it('with primitive', () => {
        const testQueryField = schema.getQueryType()?.getFields()['testList'];
        if (testQueryField == null)
            throw new Error();
        const floatType = getGraphQLStringTypeByPath_1.getGraphQLStringTypeByPath(schema, testQueryField, ['floatTest']);
        chai_1.expect(floatType).to.eq('Float');
        const intType = getGraphQLStringTypeByPath_1.getGraphQLStringTypeByPath(schema, testQueryField, ['intTest']);
        chai_1.expect(intType).to.eq('Int');
        const booleanType = getGraphQLStringTypeByPath_1.getGraphQLStringTypeByPath(schema, testQueryField, ['bool']);
        chai_1.expect(booleanType).to.eq('Boolean');
        const stringType = getGraphQLStringTypeByPath_1.getGraphQLStringTypeByPath(schema, testQueryField, ['string']);
        chai_1.expect(stringType).to.eq('String');
    });
    it('with date', () => {
        const testQueryField = schema.getQueryType()?.getFields()['testList'];
        if (testQueryField == null)
            throw new Error();
        const localDateType = getGraphQLStringTypeByPath_1.getGraphQLStringTypeByPath(schema, testQueryField, ['localDate']);
        chai_1.expect(localDateType).to.eq('Date');
        const localDateTimeType = getGraphQLStringTypeByPath_1.getGraphQLStringTypeByPath(schema, testQueryField, ['localDateTime']);
        chai_1.expect(localDateTimeType).to.eq('DateTime');
        const localTimeType = getGraphQLStringTypeByPath_1.getGraphQLStringTypeByPath(schema, testQueryField, ['localTime']);
        chai_1.expect(localTimeType).to.eq('Time');
    });
    it('with not null', () => {
        const testQueryField = schema.getQueryType()?.getFields()['testList'];
        if (testQueryField == null)
            throw new Error();
        const strictBooleanType = getGraphQLStringTypeByPath_1.getGraphQLStringTypeByPath(schema, testQueryField, ['boolPrimitive']);
        chai_1.expect(strictBooleanType).to.eq('Boolean!');
        const strictIntType = getGraphQLStringTypeByPath_1.getGraphQLStringTypeByPath(schema, testQueryField, ['bytePrimitive']);
        chai_1.expect(strictIntType).to.eq('Int!');
    });
    it('with array', () => {
        const petListField = schema.getQueryType()?.getFields()['petList'];
        if (petListField == null)
            throw new Error();
        const petListType = getGraphQLStringTypeByPath_1.getGraphQLStringTypeByPath(schema, petListField, []);
        chai_1.expect(petListType).to.eq('[PetDTO]');
    });
    it('get type by deep path', () => {
        const petField = schema.getQueryType()?.getFields()['pet'];
        if (petField == null)
            throw new Error();
        const ownerType = getGraphQLStringTypeByPath_1.getGraphQLStringTypeByPath(schema, petField, ['owner']);
        chai_1.expect(ownerType).to.eq('OwnerDTO');
        const ownerCityType = getGraphQLStringTypeByPath_1.getGraphQLStringTypeByPath(schema, petField, ['owner', 'city']);
        chai_1.expect(ownerCityType).to.eq('String');
        const ownerEmailType = getGraphQLStringTypeByPath_1.getGraphQLStringTypeByPath(schema, petField, ['owner', 'email']);
        chai_1.expect(ownerEmailType).to.eq('String');
        const petTypeType = getGraphQLStringTypeByPath_1.getGraphQLStringTypeByPath(schema, petField, ['type']);
        chai_1.expect(petTypeType).to.eq('PetTypeDTO');
        const petTypeNameType = getGraphQLStringTypeByPath_1.getGraphQLStringTypeByPath(schema, petField, ['type', 'name']);
        chai_1.expect(petTypeNameType).to.eq('String');
    });
});
//# sourceMappingURL=getGraphQLStringTypeByPath.test.js.map