"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = __importDefault(require("assert"));
const init_1 = require("../../../init");
const path_1 = __importDefault(require("path"));
const util_1 = require("util");
const fs_1 = __importDefault(require("fs"));
const test_commons_1 = require("../../test-commons");
const rimraf = util_1.promisify(require('rimraf'));
// let's test both absolute and relative path usage
const absoluteModelPath = require.resolve('../../fixtures/mpg-projectModel.json');
const modelPathScr = require.resolve('../../fixtures/project-model--scr.json');
const componentRelativeModelPath = './src/test/fixtures/mpg-projectModel.json';
const answers = require('../../fixtures/answers.js');
const stringIdAnswers = require('../../fixtures/answers/string-id-management-table.js');
const REACT_DIR = path_1.default.join(process.cwd(), `src/test/generated/react-client`);
const COMPONENT_DIR = path_1.default.join(REACT_DIR, 'src/app/component');
const CARDS_DIR = path_1.default.join(REACT_DIR, 'src/app/entity-cards');
const CARDS_GRID_DIR = path_1.default.join(REACT_DIR, 'src/app/entity-cards-grid');
const EM_DIR = path_1.default.join(REACT_DIR, 'src/app/entity-management');
const FIXTURES_DIR = path_1.default.join(process.cwd(), `src/test/fixtures/react-client`);
const TEST_RUN_DIR = path_1.default.join(__dirname, '../../../../');
const GENERATORS_DIR = path_1.default.join(__dirname, '../../../generators');
// run each generator test from the same directory - we need it to test relative cli paths
beforeEach(() => process.chdir(TEST_RUN_DIR));
xdescribe('react generator test', () => {
    it('should generates React client app', async function () {
        await rimraf(`${REACT_DIR}/*`);
        await init_1.generate(path_1.default.join(GENERATORS_DIR, 'react-typescript', 'app'), test_commons_1.opts(REACT_DIR, null, absoluteModelPath));
        assert_1.default.ok(!fs_1.default.existsSync(`entities/base`));
        assert_1.default.ok(fs_1.default.existsSync(`enums/enums.ts`));
        test_commons_1.assertFilesPlain('src/index.tsx', REACT_DIR, FIXTURES_DIR);
        test_commons_1.assertFilesPlain('.env.development.local', REACT_DIR, FIXTURES_DIR);
        test_commons_1.assertFilesPlain('.env.production.local', REACT_DIR, FIXTURES_DIR);
    });
    it('should generate React client blank-component', async function () {
        await rimraf(`${COMPONENT_DIR}/*`);
        await init_1.generate(path_1.default.join(GENERATORS_DIR, 'react-typescript', 'blank-screen'), test_commons_1.opts(COMPONENT_DIR, answers.blankComponent, componentRelativeModelPath));
        test_commons_1.assertFilesPlain('src/app/component/BlankComponent.tsx', REACT_DIR, FIXTURES_DIR);
        await rimraf(`${COMPONENT_DIR}/*`);
        await init_1.generate(path_1.default.join(GENERATORS_DIR, 'react-typescript', 'blank-screen'), test_commons_1.opts(COMPONENT_DIR, answers.blankComponentLowCase, absoluteModelPath));
        test_commons_1.assertFilesPlain('src/app/component/BlankComponent.tsx', REACT_DIR, FIXTURES_DIR);
    });
    it('should generate React client structure', async function () {
        await rimraf(`${COMPONENT_DIR}/*`);
        await init_1.generate(path_1.default.join(GENERATORS_DIR, 'react-typescript', 'structure'), test_commons_1.opts(COMPONENT_DIR, answers.structureComponent, componentRelativeModelPath));
        test_commons_1.assertFilesPlain('src/app/component/StructureComponent.tsx', REACT_DIR, FIXTURES_DIR);
    });
    it('should generate React client entity-cards', async function () {
        await rimraf(`${CARDS_DIR}/*`);
        await init_1.generate(path_1.default.join(GENERATORS_DIR, 'react-typescript', 'entity-cards'), test_commons_1.opts(CARDS_DIR, answers.entityCards, componentRelativeModelPath));
        test_commons_1.assertFilesPlain('src/app/entity-cards/CarBrowserCards.tsx', REACT_DIR, FIXTURES_DIR);
    });
    it('should generate React client entity-cards-grid', async function () {
        await rimraf(`${CARDS_GRID_DIR}/*`);
        await init_1.generate(path_1.default.join(GENERATORS_DIR, 'react-typescript', 'entity-cards-grid'), test_commons_1.opts(CARDS_GRID_DIR, answers.entityCardsGrid, componentRelativeModelPath));
        test_commons_1.assertFilesPlain('src/app/entity-cards-grid/CarCardsGrid.tsx', REACT_DIR, FIXTURES_DIR);
    });
    // TODO Uncaught TypeError: Cannot read property '0' of undefined
    it('should generate React client entity-management', async function () {
        await rimraf(`${EM_DIR}/*`);
        await init_1.generate(path_1.default.join(GENERATORS_DIR, 'react-typescript', 'entity-management'), test_commons_1.opts(EM_DIR, answers.entityManagement, componentRelativeModelPath));
        process.chdir(TEST_RUN_DIR);
        await init_1.generate(path_1.default.join(GENERATORS_DIR, 'react-typescript', 'entity-management'), test_commons_1.opts(EM_DIR, answers.entityManagement2, absoluteModelPath));
        process.chdir(TEST_RUN_DIR);
        await init_1.generate(path_1.default.join(GENERATORS_DIR, 'react-typescript', 'entity-management'), test_commons_1.opts(EM_DIR, answers.entityManagement3, componentRelativeModelPath));
        process.chdir(TEST_RUN_DIR);
        await init_1.generate(path_1.default.join(GENERATORS_DIR, 'react-typescript', 'entity-management'), test_commons_1.opts(EM_DIR, answers.entityManagementLowCase, absoluteModelPath));
        process.chdir(TEST_RUN_DIR);
        await init_1.generate(path_1.default.join(GENERATORS_DIR, 'react-typescript', 'entity-management'), test_commons_1.opts(EM_DIR, stringIdAnswers, modelPathScr));
        process.chdir(TEST_RUN_DIR);
        test_commons_1.assertFilesPlain('src/app/entity-management/CarCards.tsx', REACT_DIR, FIXTURES_DIR);
        test_commons_1.assertFilesPlain('src/app/entity-management/CarEdit.tsx', REACT_DIR, FIXTURES_DIR);
        test_commons_1.assertFilesPlain('src/app/entity-management/CarList.tsx', REACT_DIR, FIXTURES_DIR);
        test_commons_1.assertFilesPlain('src/app/entity-management/CarTable.tsx', REACT_DIR, FIXTURES_DIR);
        test_commons_1.assertFilesPlain('src/app/entity-management/CarEditLowCase.tsx', REACT_DIR, FIXTURES_DIR);
        test_commons_1.assertFilesPlain('src/app/entity-management/CarTableLowCase.tsx', REACT_DIR, FIXTURES_DIR);
        test_commons_1.assertFilesPlain('src/app/entity-management/StringIdMgtTableEdit.tsx', REACT_DIR, FIXTURES_DIR);
        test_commons_1.assertFilesPlain('src/app/entity-management/StringIdMgtTableBrowse.tsx', REACT_DIR, FIXTURES_DIR);
    });
});
//# sourceMappingURL=react-generator.test.js.map